/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "Counter.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomCounter.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/PrivateGdomCounter.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateIntGdomCounter.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::Counter* obj)
{
    return WebCore::cacheDOMObject<WebCore::Counter, GDOMCounter>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMCounter::GDOMCounter(PassRefPtr<WebCore::Counter> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMCounter::~GDOMCounter()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "Counter.h"
#include <gdom/GdomCounter.h>
#include <gdom/PrivateGdomCounter.h>
#include <gdom/PrivateIntGdomCounter.h>
#include <gdom/GdomCounterprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomCounter, gdom_counter, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomCounterPrivate {
    class WebCore::Counter *item;
};

#define GDOM_COUNTER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_COUNTER, GdomCounterPrivate))
*/
G_END_DECLS
WebCore::Counter *
gdom_counter_get_private(GdomCounter *request)
{
    GDOMCounter *res;
    res = static_cast<GDOMCounter*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::Counter*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_IDENTIFIER,
    PROP_LIST_STYLE,
    PROP_SEPARATOR,
};


static void gdom_counter_finalize(GObject* object)
{
    /*GdomCounter* request = GDOM_COUNTER(object);*/
    /*GdomCounterPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_counter_parent_class)->finalize(object);
}

static void gdom_counter__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomCounter *self = GDOM_COUNTER(object);
    WebCore::Counter * gself = (gdom_counter_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_counter__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomCounter *self = GDOM_COUNTER(object);
    WebCore::Counter * gself = (gdom_counter_get_private(self));
    switch (prop_id) {
    case PROP_IDENTIFIER:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->identifier()));
         break;
    }
    case PROP_LIST_STYLE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->listStyle()));
         break;
    }
    case PROP_SEPARATOR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->separator()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_counter_class_init(GdomCounterClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_counter_finalize;
    g_klass->set_property = gdom_counter__set_property_fn;
    g_klass->get_property = gdom_counter__get_property_fn;

    g_object_class_install_property (g_klass, PROP_IDENTIFIER,
            g_param_spec_string ("identifier", /* name */
                "counter_identifier", /* short description */
                "read-only  gchar * Counter.identifier", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LIST_STYLE,
            g_param_spec_string ("list_style", /* name */
                "counter_list_style", /* short description */
                "read-only  gchar * Counter.list_style", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SEPARATOR,
            g_param_spec_string ("separator", /* name */
                "counter_separator", /* short description */
                "read-only  gchar * Counter.separator", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomCounterPrivate));*/
}

static void gdom_counter_init(GdomCounter* request)
{
    /*GdomCounterPrivate* priv = GDOM_COUNTER_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

